==> pointpos_api-0.0.1.tar.gz: docs/MerchantApi.md <==
# swagger.api.MerchantApi

## Load the API package
```dart
import 'package:swagger/api.dart';
```

All URIs are relative to *https://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**login**](MerchantApi.md#login) | **POST** /merchant/login | Merchant Login
[**signup**](MerchantApi.md#signup) | **POST** /merchant/signup | Merchant Signup


# **login**
> InlineResponse200 login(body)

Merchant Login

Merchant Login

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: APIKey
//swagger.api.Configuration.apiKey{'X-API-Key'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'X-API-Key'} = "Bearer";

var api_instance = new MerchantApi();
var body = new Login(); // Login | 

try { 
    var result = api_instance.login(body);
    print(result);
} catch (e) {
    print("Exception when calling MerchantApi->login: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**Login**](Login.md)|  | 

### Return type

[**InlineResponse200**](InlineResponse200.md)

### Authorization

[APIKey](../README.md#APIKey)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **signup**
> signup(body)

Merchant Signup

Merchant Signup

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: APIKey
//swagger.api.Configuration.apiKey{'X-API-Key'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'X-API-Key'} = "Bearer";
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new MerchantApi();
var body = new Signup(); // Signup | 

try { 
    api_instance.signup(body);
} catch (e) {
    print("Exception when calling MerchantApi->signup: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**Signup**](Signup.md)|  | 

### Return type

void (empty response body)

### Authorization

[APIKey](../README.md#APIKey), [JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> pointpos_api-0.0.2.tar.gz: docs/MerchantApi.md <==
# swagger.api.MerchantApi

## Load the API package
```dart
import 'package:pointpos_api/api.dart';
```

All URIs are relative to *https://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**login**](MerchantApi.md#login) | **POST** /merchant/login | Merchant Login
[**signup**](MerchantApi.md#signup) | **POST** /merchant/signup | Merchant Signup


# **login**
> InlineResponse200 login(body)

Merchant Login

Merchant Login

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: APIKey
//swagger.api.Configuration.apiKey{'X-API-Key'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'X-API-Key'} = "Bearer";

var api_instance = new MerchantApi();
var body = new Login(); // Login | 

try { 
    var result = api_instance.login(body);
    print(result);
} catch (e) {
    print("Exception when calling MerchantApi->login: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**Login**](Login.md)|  | 

### Return type

[**InlineResponse200**](InlineResponse200.md)

### Authorization

[APIKey](../README.md#APIKey)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **signup**
> signup(body)

Merchant Signup

Merchant Signup

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: APIKey
//swagger.api.Configuration.apiKey{'X-API-Key'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'X-API-Key'} = "Bearer";
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new MerchantApi();
var body = new Signup(); // Signup | 

try { 
    api_instance.signup(body);
} catch (e) {
    print("Exception when calling MerchantApi->signup: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**Signup**](Signup.md)|  | 

### Return type

void (empty response body)

### Authorization

[APIKey](../README.md#APIKey), [JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
